import Grid from 'react-css-grid'
import React from 'react';
import PropTypes from 'prop-types';
import { getStaticMapURL } from '../utils/mapbox';
import VideoItem from "./VideoItem";
import RandomItemTitle from "./SectionHeading";
import {Link} from 'react-router-dom';
import {Container, Row, Col} from 'react-bootstrap';

class RandomPlace extends React.Component {

  shufflePlace() {
    this.props.getRandomPlaceVideos();
  }

  getStaticMapURL() {
    return getStaticMapURL(this.props.place);
  }

  render() {
    console.log('random place props', this.props);
    return (
      <section className="random-item-container">
        <h2 className="section-heading">
          <span className="arabic-text random-section-title">من أماكن الارشيف</span>
          <br/>
          <span className="section-title">
          <span className='english-text bold-english-text random-section-title'> Places from the archive
        </span>
          </span>
        </h2>
        <Grid width={450}>
          {/* View all places button*/}
          <Link className="view-items-link" to="/places">
            <button className="view-all-items">
              <span className={"highlighted-text"}>
                <span className="english-text"> all places    &nbsp; </span>
               <   span className="arabic-text"> 	 جميع الأماكن	</span>
                </span>
            </button>
          </Link>
          {/* Shuffle button */}
          <button className="shuffle-button" onClick={this.shufflePlace.bind(this)}>
            <span className={"highlighted-text"}>
            <span className="english-text">Shuffle Places - </span>
            <span className="arabic-text"> مكان عشوائي </span>
            </span>
            <i className="fa fa-random"></i>
          </button>
        </Grid>

        <Container>
          <Row>
            <Col sm={4} >
              {this.props.place && (
                  <img class={"place-map"} src={this.getStaticMapURL()} />
              )}
            </Col>
            <Col sm={8} >
              <Container>
            <Row>
              {this.props.videos.map(video =>
                  <Col sm={4}>
                     <VideoItem id={video.id} key={video.id} title={video.title}/>
                  </Col>
              )}
            </Row>
              </Container>
            </Col>
          </Row>
        </Container>

        {this.props.placeName && (
          <RandomItemTitle 
            title={this.props.placeName}
            count={this.props.placeCount}
            src={'/results/place/' + this.props.placeName}
          />
        )}
      </section>

    )
  }
}

RandomPlace.propTypes = {
  placeName: PropTypes.string,
  allPlaces: PropTypes.array,
  videos: PropTypes.array,
  loading: PropTypes.bool,
  placeCount: PropTypes.number,
  getRandomPlaceVideos: PropTypes.func
};

export default (RandomPlace);